@@ -3,7 +3,7 @@ os.environ['ANSI_COLORS_DISABLED']="1"
 import shutil
 import fire
 from codemaker.makecode import gencode,write_yaml,render
-DEFAULT_MAKER_FILENAME='maker.yaml'
+DEFAULT_MAKER_FILENAME='maker.yml'
 class CLI:
     def hi(cls):
         print('Hi, I am codemaker.'.center(50, '*'))
